<!--
    ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――
    File: README.md
    Copyright 🄯 2003, 2004, 2008, 2013, 2025 Van de Bugger.
    SPDX-License-Identifier: FSFAP
    ――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――
-->

vdb-color-prompt
================

This is my favorite multi-line color prompt for Bash:

    ‹user›@‹host›:‹dir›
    $ █

The user name is printed in cyan, the host name in magenta, the current working directory in green,
the dollar sign in yellow, and the at (`@`) and colon (`:`) in the normal foreground color. The
background color is assumed to be black or dark, and the foreground color is assumen to be gray or
white.

If the user is root, the user name is printed in inverted red (black on red). If a remote (ssh)
session is detected, the host name is printed in inverted color (black on magenta).

If the environment variable `VDB_COLOR_PROMPT` is not empty, its content is printed before the
prompt:

    #‹VDB_COLOR_PROMPT›
    ‹user›@‹host›:‹dir›
    $ █

The hash sign (`#`) is printed in yellow, the value of `VDB_COLOR_PROMPR` is printed in the normal
foreground color. Note that the value of the environment variable `VDB_COLOR_PROMPT` is printed
immediately after the hash sign, without a space between them. You need to include a space to
`VDB_COLOR_PROMPT` yourself. This is an intentional decision — it makes the variable easier to work
with. I assume the variable is assigned in such way:

    VDB_COLOR_PROMPT="$VDB_COLOR_PROMPT ‹addition›"

This is intended to visualize changes in the environment. For example, consider a script that sets
up the environment for working on a project:

    #!/bin/bash
    # Go to the project's directory:
    cd ‹project directory›
    # Modify PATH so scripts and programs from project's bin directory can be easily run:
    PATH="$(realpath ./bin):$PATH"
    # Modify LD_LIBRARY_PATH so project's librarries can be found:
    LD_LIBRARY_PATH="$(realpath ./lib):$LD_LIBRARY_PATH"
    VDB_COLOR_PROMPT="$VDB_COLOR_PROMPT ‹project name›"
    bash

You start working in the standard environment, your prompt looks like this:

    ‹user›@‹host›:~
    $ █

Then you execute the script:

    # ‹project name›
    ‹user›@‹host›:‹project’s dir›
    $ █

The project name in the prompt reminds you that the environment has changed. When you are done
working on the project, press `Ctrl`+`D` to exit the inner shell and return to the standard
environment:

    ‹user›@‹host›:~
    $ █

Naming
------

In 2003 I wrote the script `bash-color-prompt.sh`.

Twenty years later, in 2023, Fedora started shipping their own `bash-color-prompt.sh` script, so I
had to rename my script to avoid collision. So now my script is called `vdb-color-prompt.sh`.

<!-- end of file -->
